demo_plugin_text_stroke
A new plugin for demo purposes of text stroke.
Getting started
To use this package, add text_scroll as a dependency in your pubspec.yaml file.
Usage
Minimal example:
TextStroke()
A new plugin for demo purposes of text stroke.
To use this package, add text_scroll as a dependency in your pubspec.yaml file.
Minimal example:
TextStroke()